#!/bin/bash
#
# Executes a processing command using input and output files named in a spool file.
# Tipically launched by a daemon in background. On success removes the spool file.
# 2007-03-14 - garancsi.tamas@ionlab.net - kovacs.zoltan@ionlab.net
#
# Usage:
# $0 "spoolfile" "processing_command" "on_success_command" 
# exit codes: 
#   0 - OK 
# 101 - spoolfile problem
# 102 - input file problem
# 103 - output file problem
# 104 - processing command problem
# 105 - postprocesing command problem

CUT="/usr/bin/cut"              # cut command call
HEAD="/usr/bin/head"            # head command call
TAIL="/usr/bin/tail"            # tail command call

EXIT_OK=0                       # success exit code

# Getting common settings (if any)
HEADERS="/etc/default/spoolprocess"
. $HEADERS

# Getting and sanitizing parameters

# spoolfile is mandatory
spoolfile=$1; shift
[ -z "$spoolfile" ]   && exit 101
[ ! -f "$spoolfile" ] && exit 101

# spoolfile's 1st line describes a mandatory inputfile
inputfile="`$HEAD -q -n1 $spoolfile`"
[ -z "$inputfile" ]   && exit 102
[ ! -f "$inputfile" ] && exit 102

# spoolfile's 2nd line describes a nonexistent outputfile
outputfile="`$HEAD -q -n2 $spoolfile | $TAIL -n1`"
[ -z "$outputfile" ] && exit 103
[ -f "$outputfile" ] && exit 103

# processing command is a mandatory executable
PROCESS="$1"; shift
[ -z "$PROCESS" ] && exit $104
[ ! -x "`echo "$PROCESS" | $CUT -d ' ' -f 1`" ] && exit 104

# postprocess command is an optional executable 
PROCESSED="$1"; shift
[ ! -z "$PROCESSED" ] && [ ! -x "`echo "$PROCESSED" | $CUT -d ' ' -f 1`" ] && exit 105

# Processing itself
export spoolfile; $PROCESS "$inputfile" "$outputfile" 2>&1 >/dev/null; RESULT=$?
if [ "$RESULT" = "$EXIT_OK" ]; then 
    [ ! -z "$PROCESSED" ] && $PROCESSED"$spoolfile" 2>&1 >/dev/null
    [ -f "$spoolfile" ] && rm -f "$spoolfile"
	exit $EXIT_OK
else
	exit $RESULT
fi
